@@ -13,7 +13,7 @@ use Filter::signatures;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 =head1 NAME
 
@@ -178,12 +178,10 @@ sub _init_cookie_jar( $self ) {
         my $save = $self->cookie_jar_options->{'write'};
         return {
             preamble => [
-                'use Path::Tiny;',
-                'use HTTP::CookieJar;',
-            ],
-            code => [
-                "HTTP::CookieJar->new->load_cookies(path('$fn')->lines),"
+                "use Path::Tiny;",
+                "use HTTP::CookieJar;",
             ],
+            code => \"HTTP::CookieJar->new->load_cookies(path('$fn')->lines),",
             postamble => [
                 "path('$fn')->spew(\$ua->cookie_jar->dump_cookies())",
             ],
@@ -193,7 +191,7 @@ sub _init_cookie_jar( $self ) {
 
 sub _pairlist( $self, $l, $prefix = "    " ) {
     return join ",\n",
-        pairmap { qq{$prefix'$a' => '$b'} } @$l
+        pairmap { my $v = ref $b ? $$b : qq{'$b'}; qq{$prefix'$a' => $v} } @$l
 }
 
 sub _build_headers( $self, $prefix = "    " ) {
@@ -215,9 +213,11 @@ snippets from C<curl> examples.
 =cut
 
 sub as_snippet( $self, %options ) {
+    $options{ prefix } ||= '';
+
     my @preamble;
     push @preamble, @{ $options{ preamble } } if $options{ preamble };
-
+    
     my $request_args = join ", ",
                                  '$r',
                            $self->_pairlist([
@@ -242,8 +242,11 @@ sub as_snippet( $self, %options ) {
             quotemeta $user,
             quotemeta $pass;
     };
+
+    @preamble = map { "$options{prefix}    $_\n" } @preamble;
+
     return <<SNIPPET;
-    @preamble
+@preamble
     my \$ua = WWW::Mechanize->new($constructor_args);$setup_credentials
     my \$r = HTTP::Request->new(
         '@{[$self->method]}' => '@{[$self->uri]}',
